@@ -18,5 +18,8 @@ read_model_frame_into_Weka <-
 function(mf)
 {
     ## For Weka, always have the response *last* in the ARFF file.
-    read_data_into_Weka(mf[c(seq(along = mf)[-1], 1)])
+    instances <- read_data_into_Weka(mf[c(seq(along = mf)[-1], 1)])
+    .jcall(instances, "V", "setClassIndex",
+           as.integer(.jcall(instances, "I", "numAttributes") - 1))
+    instances
 }
